#! Flux3D 19.1

# Physical description process
import os
INSTALL = os.environ["INSTALLFLUX"] + "/.."

# Define the simulation application and parameters
lastInstance = ApplicationMagneticAC3D(frequency='50',
                        formulationModel=MagneticACFormulationModelAutomatic(approximation=VectorPotentialApproximationNodal()),
                        scalarVariableOrder=ScalarVariableAutomaticOrder(),
                        vectorNodalVariableOrder=VectorNodalVariableAutomaticOrder(),
                        coilCoefficient=CoilCoefficientAutomatic(),
                        eFieldComputation=EFieldComputationModeWithoutComputation())

lastInstance = VariationParameterPilot(name='FREQUENCY',
                        referenceValue=50.0)

lastInstance = VariationParameterPilot(name='SLIP',
                        referenceValue=0.035)

Application[2].frequency='FREQUENCY'

# Import materials
importMaterial(fileName=INSTALL + '/Materials/FLUX_111_MATERI.DAT', materialNames=['FLU_ALUMINIUM        :','FLU_M330_35A         :'])

# Create mechanical sets 
lastInstance = MechanicalSetFixed(name='STATOR')

lastInstance = MechanicalSetRotation1Axis(name='ROTOR',
                           kinematics=RotatingMultiStatic(slip='SLIP'),
                           rotationAxis=RotationZAxis(coordSys=CoordSys['XYZ1'],
                                                      pivot=['0',
                                                             '0',
                                                             '0']))

RegionFace[ALL].deleteForce()

#Create volume regions
lastInstance = RegionVolume(name='INFINITE',
             magneticAC3D=MagneticAC3DVolumeVacuum(),
             color=Color['Turquoise'],
             visibility=Visibility['VISIBLE'],
             mechanicalSet=MechanicalSet['STATOR'])

lastInstance = RegionVolume(name='ROTOR_AIR ',
             magneticAC3D=MagneticAC3DVolumeVacuum(),
             color=Color['Turquoise'],
             visibility=Visibility['VISIBLE'],
             mechanicalSet=MechanicalSet['ROTOR'])

lastInstance = RegionVolume(name='SHAFT',
             magneticAC3D=MagneticAC3DVolumeVacuum(),
             color=Color['Turquoise'],
             visibility=Visibility['VISIBLE'],
             mechanicalSet=MechanicalSet['ROTOR'])

lastInstance = RegionVolume(name='SQUIRREL_CAGE ',
             magneticAC3D=MagneticAC3DVolumeSolidConductor(material=Material['FLU_ALUMINIUM']),
             color=Color['Turquoise'],
             visibility=Visibility['VISIBLE'],
             mechanicalSet=MechanicalSet['ROTOR'])

lastInstance = RegionVolume(name='STATOR_AIR ',
             magneticAC3D=MagneticAC3DVolumeVacuum(),
             color=Color['Turquoise'],
             visibility=Visibility['VISIBLE'],
             mechanicalSet=MechanicalSet['STATOR'])

lastInstance = RegionVolume(name='ROTOR',
             magneticAC3D=MagneticAC3DVolumeLaminatedNonConducting(sheetIronMaterial=Material['FLU_M330_35A'],
                                                                   sheetIronThickness='0.35E-3 ',
                                                                   stackingFactor='0.97',
                                                                   geometryLamination=PlaneLamination(coordSys=CoordSys['XYZ1'],
                                                                                                      directionLamination=['0',
                                                                                                                           '0',
                                                                                                                           '1'])),
             color=Color['Turquoise'],
             visibility=Visibility['VISIBLE'],
             mechanicalSet=MechanicalSet['ROTOR'])

lastInstance = RegionVolume(name='STATOR',
             magneticAC3D=MagneticAC3DVolumeLaminatedNonConducting(sheetIronMaterial=Material['FLU_M330_35A'],
                                                                   sheetIronThickness='0.35E-3 ',
                                                                   stackingFactor='0.97',
                                                                   geometryLamination=PlaneLamination(coordSys=CoordSys['XYZ1'],
                                                                                                      directionLamination=['0',
                                                                                                                           '0',
                                                                                                                           '1'])),
             color=Color['Turquoise'],
             visibility=Visibility['VISIBLE'],
             mechanicalSet=MechanicalSet['STATOR'])

assignRegionToVolumes(volume=[Volume[89],
                              Volume[90]],
                      region=RegionVolume['INFINITE'])

assignRegionToVolumes(volume=[Volume[88]],
                      region=RegionVolume['STATOR_AIR'])

assignRegionToVolumes(volume=[Volume[1]],
                      region=RegionVolume['SHAFT'])

assignRegionToVolumes(volume=[Volume[32]],
                      region=RegionVolume['ROTOR_AIR'])

assignRegionToVolumes(volume=[Volume[31]],
                      region=RegionVolume['SQUIRREL_CAGE'])

assignRegionToVolumes(volume=[Volume[5],
                              Volume[4],
                              Volume[8],
                              Volume[9],
                              Volume[12],
                              Volume[13],
                              Volume[17],
                              Volume[16],
                              Volume[22],
                              Volume[21],
                              Volume[25],
                              Volume[24],
                              Volume[27],
                              Volume[30]],
                      region=RegionVolume['SQUIRREL_CAGE'])

assignRegionToVolumes(volume=[Volume[2],
                              Volume[3],
                              Volume[6],
                              Volume[7],
                              Volume[10],
                              Volume[11],
                              Volume[15],
                              Volume[14],
                              Volume[19],
                              Volume[18],
                              Volume[20],
                              Volume[23],
                              Volume[26],
                              Volume[28],
                              Volume[29]],
                      region=RegionVolume['ROTOR'])

assignRegionToVolumes(volume=[Volume[33],
                              Volume[34],
                              Volume[35],
                              Volume[36],
                              Volume[37],
                              Volume[38],
                              Volume[39],
                              Volume[40],
                              Volume[41],
                              Volume[42],
                              Volume[43],
                              Volume[44],
                              Volume[45],
                              Volume[46],
                              Volume[47],
                              Volume[48],
                              Volume[49],
                              Volume[50],
                              Volume[51],
                              Volume[52],
                              Volume[53],
                              Volume[54],
                              Volume[55],
                              Volume[56],
                              Volume[57],
                              Volume[58],
                              Volume[59],
                              Volume[60],
                              Volume[61],
                              Volume[62],
                              Volume[63],
                              Volume[64],
                              Volume[65],
                              Volume[66],
                              Volume[67],
                              Volume[68],
                              Volume[69],
                              Volume[70],
                              Volume[71],
                              Volume[72],
                              Volume[73],
                              Volume[74],
                              Volume[75],
                              Volume[76],
                              Volume[77],
                              Volume[78],
                              Volume[79],
                              Volume[80],
                              Volume[81],
                              Volume[82],
                              Volume[83],
                              Volume[84],
                              Volume[85],
                              Volume[86],
                              Volume[87]],
                      region=RegionVolume['STATOR'])

startMacroTransaction()
RegionVolume['INFINITE','ROTOR_AIR','SHAFT','STATOR_AIR'].visibility=Visibility['INVISIBLE']

RegionVolume['STATOR'].color=Color['MAGENTA_2']

RegionVolume['ROTOR'].color=Color['Black']

RegionVolume['SQUIRREL_CAGE'].color=Color['YELLOW_2']

endMacroTransaction()

# Create the external electric circuit
macroFile = INSTALL + "/Extensions/Macros/Macros_Flux_Circuit/Circuit_3_Phases.PFM"
loadMacro(fileName=macroFile)

Circuit_3_Phases(id='CIRC',
                 isSourceV=1,
                 formSourceY=1,
                 formCoilsY=1,
                 effValue=230.94,
                 frequ=50.0,
                 resist=1.0E-4,
                 induct=1.0E-9)

# Create non-meshed coils
runPyInSilentMode('InductionMotor3DWinding.py')

result = checkPhysic()

saveProjectAs('IM3D_PHYSICS_CHECKED.FLU')
